summaryrefslogtreecommitdiffstats
path: root/ash/wm/system_modal_container_layout_manager.h
diff options
context:
space:
mode:
Diffstat (limited to 'ash/wm/system_modal_container_layout_manager.h')
-rw-r--r--ash/wm/system_modal_container_layout_manager.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/ash/wm/system_modal_container_layout_manager.h b/ash/wm/system_modal_container_layout_manager.h
index 5818708..59c0eac 100644
--- a/ash/wm/system_modal_container_layout_manager.h
+++ b/ash/wm/system_modal_container_layout_manager.h
@@ -22,9 +22,11 @@ class EventFilter;
namespace gfx {
class Rect;
}
+namespace views {
+class Widget;
+}
namespace ash {
-class DimWindow;
// LayoutManager for the modal window container.
// System modal windows which are centered on the screen will be kept centered
@@ -96,9 +98,9 @@ class ASH_EXPORT SystemModalContainerLayoutManager
// The container that owns the layout manager.
aura::Window* container_;
// A window that dims the windows behind the modal window(s) being
// shown in |container_|.
- DimWindow* modal_background_;
+ views::Widget* modal_background_;
// A stack of modal windows. Only the topmost can receive events.
std::vector<aura::Window*> modal_windows_;
@@ -96,9 +98,9 @@ class ASH_EXPORT SystemModalContainerLayoutManager
// The container that owns the layout manager.
aura::Window* container_;
- // A window that dims the windows behind the modal window(s) being
+ // A widget that dims the windows behind the modal window(s) being
// shown in |container_|.